pub enum StatePayload {
Online {
timestamp: u64,
},
Offline {
timestamp: u64,
},
}Expand description
An enum representing the different type message published on a STATE topic.
Variants
Implementations
Sourceimpl StatePayload
impl StatePayload
Sourcepub fn get_publish_quality_retain(&self) -> (QoS, bool)
pub fn get_publish_quality_retain(&self) -> (QoS, bool)
Get the QoS and retain settings that the State message should be published with